# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/cifar10.ipynb.

# %% auto 0
__all__ = ['CIFAR10']

# %% ../nbs/cifar10.ipynb 3
from fastai.vision.all import *

import fastai_datasets.patches

# %% ../nbs/cifar10.ipynb 4
def CIFAR10():
    return DataBlock(
        blocks=(ImageBlock, CategoryBlock),
        get_items=get_image_files,
        get_y=parent_label,
        splitter=GrandparentSplitter('train', 'test'),
    ).datasets(untar_data(URLs.CIFAR))
