# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/fastai-datasets',
                'doc_host': 'https://Irad-Zehavi.github.io',
                'git_url': 'https://github.com/Irad-Zehavi/fastai-datasets',
                'lib_path': 'fastai_datasets'},
  'syms': { 'fastai_datasets.all': {},
            'fastai_datasets.cifar10': {'fastai_datasets.cifar10.CIFAR10': ('cifar10.html#cifar10', 'fastai_datasets/cifar10.py')},
            'fastai_datasets.imagenette': { 'fastai_datasets.imagenette.Imagenette': ( 'imagenette.html#imagenette',
                                                                                       'fastai_datasets/imagenette.py')},
            'fastai_datasets.lfw': { 'fastai_datasets.lfw.LFW': ('Facial Recognition/lfw.html#lfw', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW.__init__': ( 'Facial Recognition/lfw.html#lfw.__init__',
                                                                           'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW._fetch_file': ( 'Facial Recognition/lfw.html#lfw._fetch_file',
                                                                              'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW._get_path': ( 'Facial Recognition/lfw.html#lfw._get_path',
                                                                            'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW._load': ('Facial Recognition/lfw.html#lfw._load', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW._parse_items': ( 'Facial Recognition/lfw.html#lfw._parse_items',
                                                                               'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW._url': ('Facial Recognition/lfw.html#lfw._url', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFW.test': ('Facial Recognition/lfw.html#lfw.test', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWDevMixin': ( 'Facial Recognition/lfw.html#lfwdevmixin',
                                                                          'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWDevMixin.dev': ( 'Facial Recognition/lfw.html#lfwdevmixin.dev',
                                                                              'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPairs': ('Facial Recognition/lfw.html#lfwpairs', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPairsMixin': ( 'Facial Recognition/lfw.html#lfwpairsmixin',
                                                                            'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPairsMixin._load': ( 'Facial Recognition/lfw.html#lfwpairsmixin._load',
                                                                                  'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPairsMixin._parse_items': ( 'Facial '
                                                                                         'Recognition/lfw.html#lfwpairsmixin._parse_items',
                                                                                         'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPeople': ('Facial Recognition/lfw.html#lfwpeople', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPeople._load': ( 'Facial Recognition/lfw.html#lfwpeople._load',
                                                                              'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.LFWPeople._parse_items': ( 'Facial Recognition/lfw.html#lfwpeople._parse_items',
                                                                                     'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.SLLFWPairs': ('Facial Recognition/lfw.html#sllfwpairs', 'fastai_datasets/lfw.py'),
                                     'fastai_datasets.lfw.SLLFWPairs._parse_items': ( 'Facial Recognition/lfw.html#sllfwpairs._parse_items',
                                                                                      'fastai_datasets/lfw.py')},
            'fastai_datasets.mnist': { 'fastai_datasets.mnist.MNIST': ('mnist.html#mnist', 'fastai_datasets/mnist.py'),
                                       'fastai_datasets.mnist.TinyMNIST': ('mnist.html#tinymnist', 'fastai_datasets/mnist.py')},
            'fastai_datasets.pairs': { 'fastai_datasets.pairs.ImagePair': ('pairs.html#imagepair', 'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.ImagePair.create': ( 'pairs.html#imagepair.create',
                                                                                   'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.ImagePair.show': ('pairs.html#imagepair.show', 'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.Pairs': ('pairs.html#pairs', 'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.Sameness': ('pairs.html#sameness', 'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.Sameness.__init__': ( 'pairs.html#sameness.__init__',
                                                                                    'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.Sameness.encodes': ( 'pairs.html#sameness.encodes',
                                                                                   'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs._pairs_for_split': ( 'pairs.html#_pairs_for_split',
                                                                                   'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.show_batch': ('pairs.html#show_batch', 'fastai_datasets/pairs.py'),
                                       'fastai_datasets.pairs.show_results': ('pairs.html#show_results', 'fastai_datasets/pairs.py')},
            'fastai_datasets.patches': { 'fastai_datasets.patches.DataLoader.__add__': ( 'Core/patches.html#dataloader.__add__',
                                                                                         'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.DataLoader.by_target': ( 'Core/patches.html#dataloader.by_target',
                                                                                           'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.DataLoader.random_sub_dl': ( 'Core/patches.html#dataloader.random_sub_dl',
                                                                                               'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.DataLoader.sub_dl': ( 'Core/patches.html#dataloader.sub_dl',
                                                                                        'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.__add__': ( 'Core/patches.html#datasets.__add__',
                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.__repr__': ( 'Core/patches.html#datasets.__repr__',
                                                                                        'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.__sub__': ( 'Core/patches.html#datasets.__sub__',
                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.by_target': ( 'Core/patches.html#datasets.by_target',
                                                                                         'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.dl': ( 'Core/patches.html#datasets.dl',
                                                                                  'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.dls': ( 'Core/patches.html#datasets.dls',
                                                                                   'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.i2t': ( 'Core/patches.html#datasets.i2t',
                                                                                   'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.load': ( 'Core/patches.html#datasets.load',
                                                                                    'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.plot_class_distribution': ( 'Core/patches.html#datasets.plot_class_distribution',
                                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.random_sub_dsets': ( 'Core/patches.html#datasets.random_sub_dsets',
                                                                                                'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.resplit': ( 'Core/patches.html#datasets.resplit',
                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.sub_dsets': ( 'Core/patches.html#datasets.sub_dsets',
                                                                                         'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Datasets.subsets': ( 'Core/patches.html#datasets.subsets',
                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.ListToTuple': ( 'Core/patches.html#listtotuple',
                                                                                  'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.ListToTuple.encodes': ( 'Core/patches.html#listtotuple.encodes',
                                                                                          'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.TfmdLists.__add__': ( 'Core/patches.html#tfmdlists.__add__',
                                                                                        'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.TfmdLists.sublist': ( 'Core/patches.html#tfmdlists.sublist',
                                                                                        'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.TfmdLists.subset': ( 'Core/patches.html#tfmdlists.subset',
                                                                                       'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches.Union[(Pipeline, Transform)].__eq__': ( 'Core/patches.html#union[(pipeline, '
                                                                                                          'transform)].__eq__',
                                                                                                          'fastai_datasets/patches.py'),
                                         'fastai_datasets.patches._dl_args': ('Core/patches.html#_dl_args', 'fastai_datasets/patches.py')},
            'fastai_datasets.pfr': { 'fastai_datasets.pfr.PinterestFaces': ( 'Facial Recognition/pfr.html#pinterestfaces',
                                                                             'fastai_datasets/pfr.py')},
            'fastai_datasets.utils': { 'fastai_datasets.utils.data_path': ('Core/utils.html#data_path', 'fastai_datasets/utils.py'),
                                       'fastai_datasets.utils.fetch_file': ('Core/utils.html#fetch_file', 'fastai_datasets/utils.py'),
                                       'fastai_datasets.utils.mtcnn_aligned': ('Core/utils.html#mtcnn_aligned', 'fastai_datasets/utils.py'),
                                       'fastai_datasets.utils.return_list': ('Core/utils.html#return_list', 'fastai_datasets/utils.py')}}}
